@@ -1,5 +1,5 @@
 use crate::dtos::{CalendarDTO, EventWithInstancesDTO};
-use nettu_scheduler_domain::{Calendar, EventInstance, ID};
+use nettu_scheduler_domain::{Calendar, EventInstance, Tz, Weekday, ID};
 use serde::{Deserialize, Serialize};
 
 #[derive(Deserialize, Serialize)]
@@ -18,7 +18,7 @@ impl CalendarResponse {
 
 pub mod create_calendar {
     use super::*;
-    use nettu_scheduler_domain::Metadata;
+    use nettu_scheduler_domain::{Metadata, Weekday};
 
     #[derive(Deserialize)]
     pub struct PathParams {
@@ -28,16 +28,19 @@ pub mod create_calendar {
     #[derive(Deserialize, Serialize)]
     #[serde(rename_all = "camelCase")]
     pub struct RequestBody {
-        pub timezone: String,
-        #[serde(default)]
-        pub week_start: isize,
-        #[serde(default)]
+        pub timezone: Tz,
+        #[serde(default = "default_weekday")]
+        pub week_start: Weekday,
         pub metadata: Option<Metadata>,
     }
 
     pub type APIResponse = CalendarResponse;
 }
 
+fn default_weekday() -> Weekday {
+    Weekday::Mon
+}
+
 pub mod add_sync_calendar {
     use super::*;
     use nettu_scheduler_domain::IntegrationProvider;
@@ -255,7 +258,7 @@ pub mod get_user_freebusy {
 
 pub mod update_calendar {
     use super::*;
-    use nettu_scheduler_domain::Metadata;
+    use nettu_scheduler_domain::{Metadata, Weekday};
 
     #[derive(Deserialize)]
     pub struct PathParams {
@@ -266,8 +269,8 @@ pub mod update_calendar {
     #[serde(rename_all = "camelCase")]
     pub struct CalendarSettings {
         #[serde(default)]
-        pub week_start: Option<isize>,
-        pub timezone: Option<String>,
+        pub week_start: Option<Weekday>,
+        pub timezone: Option<Tz>,
     }
 
     #[derive(Deserialize, Serialize)]
