@@ -33,9 +33,12 @@ pub mod create_event {
         pub calendar_id: ID,
         pub start_ts: i64,
         pub duration: i64,
+        #[serde(default)]
         pub busy: Option<bool>,
+        #[serde(default)]
         pub recurrence: Option<RRuleOptions>,
-        pub reminder: Option<CalendarEventReminder>,
+        #[serde(default)]
+        pub reminders: Vec<CalendarEventReminder>,
         #[serde(default)]
         pub service_id: Option<ID>,
         #[serde(default)]
@@ -134,13 +137,20 @@ pub mod update_event {
     #[derive(Deserialize, Serialize)]
     #[serde(rename_all = "camelCase")]
     pub struct RequestBody {
+        #[serde(default)]
         pub start_ts: Option<i64>,
+        #[serde(default)]
         pub duration: Option<i64>,
+        #[serde(default)]
         pub busy: Option<bool>,
+        #[serde(default)]
         pub recurrence: Option<RRuleOptions>,
+        #[serde(default)]
         pub service_id: Option<ID>,
+        #[serde(default)]
         pub exdates: Option<Vec<i64>>,
-        pub reminder: Option<CalendarEventReminder>,
+        #[serde(default)]
+        pub reminders: Option<Vec<CalendarEventReminder>>,
         #[serde(default)]
         pub metadata: Option<Metadata>,
     }
@@ -153,19 +163,50 @@ pub mod update_event {
     pub type APIResponse = CalendarEventResponse;
 }
 
-pub mod send_account_event_reminders {
+pub mod send_event_reminders {
     use super::*;
 
-    #[derive(Serialize)]
+    #[derive(Debug)]
+    pub struct AccountEventReminder {
+        pub event: CalendarEvent,
+        pub identifier: String,
+    }
+
+    #[derive(Debug, Clone, Serialize, Deserialize)]
     #[serde(rename_all = "camelCase")]
     pub struct AccountEventRemindersDTO {
-        events: Vec<CalendarEventDTO>,
+        event: CalendarEventDTO,
+        identifier: String,
     }
 
     impl AccountEventRemindersDTO {
-        pub fn new(events: Vec<CalendarEvent>) -> Self {
+        pub fn new(account_event_reminder: AccountEventReminder) -> Self {
             Self {
-                events: events.into_iter().map(CalendarEventDTO::new).collect(),
+                event: CalendarEventDTO::new(account_event_reminder.event),
+                identifier: account_event_reminder.identifier,
+            }
+        }
+    }
+
+    #[derive(Debug)]
+    pub struct AccountReminders {
+        pub reminders: Vec<AccountEventReminder>,
+    }
+
+    #[derive(Debug, Clone, Serialize, Deserialize)]
+    #[serde(rename_all = "camelCase")]
+    pub struct AccountRemindersDTO {
+        reminders: Vec<AccountEventRemindersDTO>,
+    }
+
+    impl AccountRemindersDTO {
+        pub fn new(acc_reminders: AccountReminders) -> Self {
+            Self {
+                reminders: acc_reminders
+                    .reminders
+                    .into_iter()
+                    .map(AccountEventRemindersDTO::new)
+                    .collect(),
             }
         }
     }
